@@ -1,10 +1,16 @@
 from rest_framework import serializers
 
 from ..models import Media, MediaFolder
+from ..storages import OverwriteStorage
 from .base import BaseTranslatableModelSerializer
 
 
 class MediaListSerializer(BaseTranslatableModelSerializer):
+    is_image = serializers.SerializerMethodField("get_is_image")
+
+    def get_is_image(self, obj):
+        return obj.is_image
+
     class Meta:
         model = Media
         fields = "__all__"
@@ -12,6 +18,7 @@ class MediaListSerializer(BaseTranslatableModelSerializer):
 
 class MediaSerializer(BaseTranslatableModelSerializer):
     links = serializers.SerializerMethodField("get_linked_instances")
+    is_image = serializers.SerializerMethodField("get_is_image")
 
     class Meta:
         model = Media
@@ -35,6 +42,20 @@ class MediaSerializer(BaseTranslatableModelSerializer):
                     )
         return result
 
+    def update(self, instance, data):
+        same_url = self.initial_data.get("same_url", False)
+        if same_url:
+            new_file = data.pop("file", None)
+            if new_file:
+                instance = super().update(instance, data)
+                instance.file.storage = OverwriteStorage()
+                instance.file.save(instance.file.name, new_file, save=True)
+                return instance
+        return super().update(instance, data)
+
+    def get_is_image(self, obj):
+        return obj.is_image
+
 
 class MediaFolderSerializer(BaseTranslatableModelSerializer):
     icon = MediaSerializer(read_only=True)
