@@ -7,12 +7,13 @@ register = template.Library()
 
 @register.filter(name="filter_content")
 def filter_content(page, args):
+    curr_lang = get_language()
     try:
-        content = page.contents.get(identifier=args)
+        content = page.contents.language(curr_lang).get(identifier=args)
     except page.contents.model.DoesNotExist:
         content, _ = page.contents.get_or_create(identifier=args)
-    if get_language() not in content.get_available_languages():
-        content.translate(get_language())
+    if curr_lang not in content.translations.all_languages():
+        content.translate(curr_lang)
         content.save()
     return content
 
